@@ -5,7 +5,7 @@ Lazy::Utils - Utilities for lazy
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =head1 SYNOPSIS
 
@@ -23,17 +23,18 @@ use FindBin;
 use Cwd;
 use File::Basename;
 use JSON;
+use Pod::Text;
 
 
 BEGIN
 {
 	require Exporter;
 	# set the version for version checking
-	our $VERSION     = '1.05';
+	our $VERSION     = '1.06';
 	# Inherit from Exporter to export functions and variables
 	our @ISA         = qw(Exporter);
 	# Functions and variables which are exported by default
-	our @EXPORT      = qw(trim ltrim rtrim file_get_contents file_put_contents shellmeta _system bashReadLine commandArgs cmdArgs whereisBin fileCache);
+	our @EXPORT      = qw(trim ltrim rtrim file_get_contents file_put_contents shellmeta _system bashReadLine commandArgs cmdArgs whereisBin fileCache getPodText);
 	# Functions and variables which can be optionally exported
 	our @EXPORT_OK   = qw();
 }
@@ -139,20 +140,23 @@ sub file_put_contents
 	return $result;
 }
 
-=head3 shellmeta($s)
+=head3 shellmeta($s, $whitespace)
 
 escapes metacharacters of double-quoted shell string
 
 $s: I<double-quoted shell string>
 
+$whitespace: I<escape whitespace characters, by default 0>
+
 return value: I<escaped string>
 
 =cut
 sub shellmeta
 {
-	my ($s) = @_;
+	my ($s, $whitespace) = @_;
 	return unless defined $s;
 	$s =~ s/(\\|\"|\$)/\\$1/g;
+	$s =~ s/(\s)/\\$1/g if $whitespace;
 	return $s;
 }
 
@@ -315,12 +319,13 @@ $name: I<binary name>
 
 $path: I<search path, by default "/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin">
 
-return value: I<binary path founded in search path, otherwise undef>
+return value: I<array of binary path founded in search path>
 
 =cut
 sub whereisBin
 {
 	my ($name, $path) = @_;
+	return () unless $name;
 	$path = "/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin" unless $path;
 	return grep(-x $_, map("$_/$name", split(":", $path)));
 }
@@ -412,6 +417,45 @@ sub fileCache
 	return $result;
 }
 
+=head3 getPodText($fileName, $section)
+
+gets a text of pod contents in given file
+
+$fileName: I<file name of searching pod, by default running file>
+
+$section: I<searching head1 section of pod, by default undef gets all of contents>
+
+return value: I<text of pod, otherwise undef if an error occurs>
+
+=cut
+sub getPodText
+{
+	my ($fileName, $section) = @_;
+	$fileName = "$FindBin::Bin/$FindBin::Script" unless $fileName;
+	return unless -e $fileName;
+	my $parser = Pod::Text->new();
+	my $text;
+	$parser->output_string(\$text);
+	eval { $parser->parse_file($fileName) };
+	return if $@;
+	$section = ltrim($section) if $section;
+	return $text unless $section;
+	my @text = split(/^/m, $text);
+	$text = "";
+	for my $line (@text)
+	{
+		chomp $line;
+		unless ($text)
+		{
+			$text = "$line\n" if $line eq $section;
+			next;
+		}
+		last unless not $line or $line =~ /^\s+/;
+		$text .= "$line\n";
+	}
+	return $text;
+}
+
 
 1;
 __END__
@@ -454,6 +498,10 @@ File::Basename
 
 JSON
 
+=item *
+
+Pod::Text
+
 =back
 
 =head1 REPOSITORY
